@@ -41,6 +41,11 @@ module RakeCompilerDock
         user = options.fetch(:username){ current_user }
         group = options.fetch(:groupname){ current_group }
 
+        ruby_version = options[:ruby] || ENV['RCD_RUBY_VERSION']
+        rbenv_opts = if ruby_version
+          ["-e", "RBENV_VERSION=#{ruby_version}"]
+        end
+
         platforms(options).split(" ").each do |platform|
           image_name = container_image_name(options.merge(platform: platform))
 
@@ -73,6 +78,7 @@ module RakeCompilerDock
               "-e", "RCD_HOST_RUBY_PLATFORM=#{RUBY_PLATFORM}",
               "-e", "RCD_HOST_RUBY_VERSION=#{RUBY_VERSION}",
               "-e", "RCD_IMAGE=#{image_name}",
+              *rbenv_opts,
               "-w", make_valid_path(workdir),
               *docker_opts,
               image_name,
@@ -167,7 +173,7 @@ module RakeCompilerDock
 
           "%s/rake-compiler-dock-image:%s-%s%s" % [
             container_registry,
-            options.fetch(:version) { IMAGE_VERSION },
+            options.fetch(:version) { image_version },
             container_rubyvm(options),
             container_jrubyvm?(options) ? "" : "-#{options.fetch(:platform)}",
           ]
@@ -178,6 +184,10 @@ module RakeCompilerDock
         ENV['CONTAINER_REGISTRY'] || "ghcr.io/rake-compiler"
       end
 
+      def image_version
+        ENV['RCD_IMAGE_VERSION'] || IMAGE_VERSION
+      end
+
       def container_rubyvm(options={})
         return "jruby" if options[:platform] == "jruby"
         options.fetch(:rubyvm) { ENV['RCD_RUBYVM'] } || "mri"
